==> isddc-1.0.0.tar.gz: isddc-1.0.0/isddc/isddc_dbpool.py <==
"""Database Connection Pool
Secondary encapsulation of `DBUtils`.

:param: creator
    数据库模块名称

:param: mincached
    初始化时，连接池中至少创建的空闲的连接，0表示不创建

:param: maxcached
    连接池中最多闲置的连接，0和None表示不限制

:param: maxshared
    连接池中最多共享的连接数量，0和None表示全部共享（这个参数不管指定多少，最后都会是0）
    因为pymysql和MySQLdb等模块的threadsafety都为1，
    所以值无论设置为多少，_maxshared永远为0，所以永远是所有连接都共享

:param: maxconnections
    连接池允许的最大连接数，0和None表示不限制连接数

:param: blocking
    连接池中如果没有可用连接后，是否阻塞等待，True:等待 False:不等待，直接报错

:param: maxusage
    一个连接最多可被使用的次数，None表示无限制

:param: setsession
    开始会话前执行的命令列表，如: ['set datastyle to ...', 'set time zone ...']

:param: ping
    Ping MySQL服务端，检查服务是否可用
    0: 从来没有  1: 从池中提取时（默认） 2: 创建游标时  4: 执行查询时  7: 总是

:param: *args **kwargs
    数据库膜拜参数
"""
import sys

from dbutils.pooled_db import PooledDB

from . import idec
from . import idict
from . import imysql

__default__: PooledDB


@idec.Retry('InitDBPool', cycle=10)
def __init__(name: str, conf: idict) -> PooledDB:
    conf.creator = sys.modules[conf.creator]
    return PooledDB(**conf)


class mysql(imysql.Transaction):

    def __new__(
            cls, sql: str = None, one: bool = False,
            datastyle=dict, pool: PooledDB = None):
        """Is execute sql"""
        if sql is None or isinstance(sql, PooledDB):
            return object.__new__(cls)

        pool = pool or __default__

        conn = pool.connection()
        conn.ping(reconnect=True)

        cur = conn.cursor(cls._datastyle[datastyle])

        result: int = cur.execute(sql)

        conn.commit()
        # You should execute the `conn.commit()`,
        # even if the SQL is `select ...`,
        # otherwise this connection will not be able to
        # query the data written by other connections.

        if not sql.lstrip()[:6].upper().startswith('SELECT'):
            return result

        queryset = cur.fetchall()

        if datastyle is dict:
            queryset = cls.__upgrade_datastyle__(cls, queryset)

        cur.close()

        conn.close()
        # This is not to close the connection, but to
        # return the connection to the connection pool.

        return queryset[0] if one else queryset

    def __init__(
            self, sql=None,
            one: bool = False,
            datastyle=dict,
            pool: PooledDB = None):
        pool = sql or pool or __default__

        self.conn = pool.connection()
        self.cur = self.conn.cursor(self._datastyle[datastyle])
        self.datastyle = datastyle

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if exc_type or exc_val or exc_tb:
            self.conn.rollback()
        self.conn.commit()
        self.cur.close()
        self.conn.close()

==> isddc-1.1.0.tar.gz: isddc-1.1.0/isddc/isddc_dbpool.py <==
"""Database Connection Pool
Secondary encapsulation of `DBUtils`.

:param: creator
    数据库模块名称

:param: mincached
    初始化时，连接池中至少创建的空闲的连接，0表示不创建

:param: maxcached
    连接池中最多闲置的连接，0和None表示不限制

:param: maxshared
    连接池中最多共享的连接数量，0和None表示全部共享（这个参数不管指定多少，最后都会是0）
    因为pymysql和MySQLdb等模块的threadsafety都为1，
    所以值无论设置为多少，_maxshared永远为0，所以永远是所有连接都共享

:param: maxconnections
    连接池允许的最大连接数，0和None表示不限制连接数

:param: blocking
    连接池中如果没有可用连接后，是否阻塞等待，True:等待 False:不等待，直接报错

:param: maxusage
    一个连接最多可被使用的次数，None表示无限制

:param: setsession
    开始会话前执行的命令列表，如: ['set datastyle to ...', 'set time zone ...']

:param: ping
    Ping MySQL服务端，检查服务是否可用
    0: 从来没有  1: 从池中提取时（默认） 2: 创建游标时  4: 执行查询时  7: 总是

:param: *args **kwargs
    数据库膜拜参数
"""
import sys

from dbutils.pooled_db import PooledDB

from . import idec
from . import idict
from . import imysql

__default__: PooledDB


@idec.Retry('InitDBPool', cycle=10)
def __init__(name: str, conf: idict, **kw) -> PooledDB:
    conf.creator = sys.modules[conf.creator]
    return PooledDB(**conf)


class mysql(imysql.Transaction):

    def __new__(
            cls, sql: str = None, one: bool = False,
            datastyle=dict, pool: PooledDB = None):
        """Is execute sql"""
        if sql is None or isinstance(sql, PooledDB):
            return object.__new__(cls)

        pool = pool or __default__

        conn = pool.connection()
        conn.ping(reconnect=True)

        cur = conn.cursor(cls._datastyle[datastyle])

        result: int = cur.execute(sql)

        conn.commit()
        # You should execute the `conn.commit()`,
        # even if the SQL is `select ...`,
        # otherwise this connection will not be able to
        # query the data written by other connections.

        if not sql.lstrip()[:6].upper().startswith('SELECT'):
            return result

        queryset = cur.fetchall()

        if datastyle is dict:
            queryset = cls.__upgrade_datastyle__(cls, queryset)

        cur.close()

        conn.close()
        # This is not to close the connection, but to
        # return the connection to the connection pool.

        return queryset[0] if one else queryset

    def __init__(
            self, sql=None,
            one: bool = False,
            datastyle=dict,
            pool: PooledDB = None):
        pool = sql or pool or __default__

        self.conn = pool.connection()
        self.cur = self.conn.cursor(self._datastyle[datastyle])
        self.datastyle = datastyle

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if exc_type or exc_val or exc_tb:
            self.conn.rollback()
        self.conn.commit()
        self.cur.close()
        self.conn.close()
